@@ -695,560 +695,573 @@ static int oqsx_gen_set_params(void *genctx, const OSSL_PARAM params[]) {
 }
 
 ///// OQS_TEMPLATE_FRAGMENT_KEYMGMT_CONSTRUCTORS_START
-static void *dilithium2_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_2,
-                        "dilithium2", KEY_TYPE_SIG, NULL, 128, 0, 0);
-}
-
-static void *dilithium2_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_2,
-                         "dilithium2", 0, 128, 0, 0);
-}
-static void *p256_dilithium2_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_2,
-                        "p256_dilithium2", KEY_TYPE_HYB_SIG, NULL, 128, 1, 0);
-}
-
-static void *p256_dilithium2_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_2,
-                         "p256_dilithium2", KEY_TYPE_HYB_SIG, 128, 1, 0);
-}
-static void *rsa3072_dilithium2_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_2,
-                        "rsa3072_dilithium2", KEY_TYPE_HYB_SIG, NULL, 128, 2,
-                        0);
-}
-
-static void *rsa3072_dilithium2_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_2,
-                         "rsa3072_dilithium2", KEY_TYPE_HYB_SIG, 128, 2, 0);
-}
-static void *dilithium3_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_3,
-                        "dilithium3", KEY_TYPE_SIG, NULL, 192, 3, 0);
-}
-
-static void *dilithium3_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_3,
-                         "dilithium3", 0, 192, 3, 0);
-}
-static void *p384_dilithium3_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_3,
-                        "p384_dilithium3", KEY_TYPE_HYB_SIG, NULL, 192, 4, 0);
-}
-
-static void *p384_dilithium3_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_3,
-                         "p384_dilithium3", KEY_TYPE_HYB_SIG, 192, 4, 0);
-}
-static void *dilithium5_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_5,
-                        "dilithium5", KEY_TYPE_SIG, NULL, 256, 5, 0);
-}
-
-static void *dilithium5_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_5,
-                         "dilithium5", 0, 256, 5, 0);
-}
-static void *p521_dilithium5_new_key(void *provctx) {
-    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_dilithium_5,
-                        "p521_dilithium5", KEY_TYPE_HYB_SIG, NULL, 256, 6, 0);
-}
-
-static void *p521_dilithium5_gen_init(void *provctx, int selection) {
-    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_dilithium_5,
-                         "p521_dilithium5", KEY_TYPE_HYB_SIG, 256, 6, 0);
-}
 
 static void *mldsa44_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44", KEY_TYPE_SIG, NULL, 128, 7, 0);
+                        "mldsa44", KEY_TYPE_SIG, NULL, 128, 0, 0);
 }
 
 static void *mldsa44_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44, "mldsa44",
-                         0, 128, 7, 0);
+                         0, 128, 0, 0);
 }
 static void *p256_mldsa44_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "p256_mldsa44", KEY_TYPE_HYB_SIG, NULL, 128, 8, 0);
+                        "p256_mldsa44", KEY_TYPE_HYB_SIG, NULL, 128, 1, 0);
 }
 
 static void *p256_mldsa44_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "p256_mldsa44", KEY_TYPE_HYB_SIG, 128, 8, 0);
+                         "p256_mldsa44", KEY_TYPE_HYB_SIG, 128, 1, 0);
 }
 static void *rsa3072_mldsa44_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "rsa3072_mldsa44", KEY_TYPE_HYB_SIG, NULL, 128, 9, 0);
+                        "rsa3072_mldsa44", KEY_TYPE_HYB_SIG, NULL, 128, 2, 0);
 }
 
 static void *rsa3072_mldsa44_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "rsa3072_mldsa44", KEY_TYPE_HYB_SIG, 128, 9, 0);
+                         "rsa3072_mldsa44", KEY_TYPE_HYB_SIG, 128, 2, 0);
 }
 static void *mldsa44_pss2048_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_pss2048", KEY_TYPE_CMP_SIG, NULL, 112, 10, 0);
+                        "mldsa44_pss2048", KEY_TYPE_CMP_SIG, NULL, 112, 3, 0);
 }
 
 static void *mldsa44_pss2048_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_pss2048", KEY_TYPE_CMP_SIG, 112, 10, 0);
+                         "mldsa44_pss2048", KEY_TYPE_CMP_SIG, 112, 3, 0);
 }
 static void *mldsa44_rsa2048_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, NULL, 112, 11, 0);
+                        "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, NULL, 112, 4, 0);
 }
 
 static void *mldsa44_rsa2048_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, 112, 11, 0);
+                         "mldsa44_rsa2048", KEY_TYPE_CMP_SIG, 112, 4, 0);
 }
 static void *mldsa44_ed25519_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 12, 0);
+                        "mldsa44_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 5, 0);
 }
 
 static void *mldsa44_ed25519_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_ed25519", KEY_TYPE_CMP_SIG, 128, 12, 0);
+                         "mldsa44_ed25519", KEY_TYPE_CMP_SIG, 128, 5, 0);
 }
 static void *mldsa44_p256_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_p256", KEY_TYPE_CMP_SIG, NULL, 128, 13, 0);
+                        "mldsa44_p256", KEY_TYPE_CMP_SIG, NULL, 128, 6, 0);
 }
 
 static void *mldsa44_p256_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_p256", KEY_TYPE_CMP_SIG, 128, 13, 0);
+                         "mldsa44_p256", KEY_TYPE_CMP_SIG, 128, 6, 0);
 }
 static void *mldsa44_bp256_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_44,
-                        "mldsa44_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 14, 0);
+                        "mldsa44_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 7, 0);
 }
 
 static void *mldsa44_bp256_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_44,
-                         "mldsa44_bp256", KEY_TYPE_CMP_SIG, 256, 14, 0);
+                         "mldsa44_bp256", KEY_TYPE_CMP_SIG, 256, 7, 0);
 }
 static void *mldsa65_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65", KEY_TYPE_SIG, NULL, 192, 15, 0);
+                        "mldsa65", KEY_TYPE_SIG, NULL, 192, 8, 0);
 }
 
 static void *mldsa65_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65, "mldsa65",
-                         0, 192, 15, 0);
+                         0, 192, 8, 0);
 }
 static void *p384_mldsa65_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "p384_mldsa65", KEY_TYPE_HYB_SIG, NULL, 192, 16, 0);
+                        "p384_mldsa65", KEY_TYPE_HYB_SIG, NULL, 192, 9, 0);
 }
 
 static void *p384_mldsa65_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "p384_mldsa65", KEY_TYPE_HYB_SIG, 192, 16, 0);
+                         "p384_mldsa65", KEY_TYPE_HYB_SIG, 192, 9, 0);
 }
 static void *mldsa65_pss3072_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_pss3072", KEY_TYPE_CMP_SIG, NULL, 128, 17, 0);
+                        "mldsa65_pss3072", KEY_TYPE_CMP_SIG, NULL, 128, 10, 0);
 }
 
 static void *mldsa65_pss3072_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_pss3072", KEY_TYPE_CMP_SIG, 128, 17, 0);
+                         "mldsa65_pss3072", KEY_TYPE_CMP_SIG, 128, 10, 0);
 }
 static void *mldsa65_rsa3072_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, NULL, 128, 18, 0);
+                        "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, NULL, 128, 11, 0);
 }
 
 static void *mldsa65_rsa3072_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, 128, 18, 0);
+                         "mldsa65_rsa3072", KEY_TYPE_CMP_SIG, 128, 11, 0);
 }
 static void *mldsa65_p256_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_p256", KEY_TYPE_CMP_SIG, NULL, 128, 19, 0);
+                        "mldsa65_p256", KEY_TYPE_CMP_SIG, NULL, 128, 12, 0);
 }
 
 static void *mldsa65_p256_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_p256", KEY_TYPE_CMP_SIG, 128, 19, 0);
+                         "mldsa65_p256", KEY_TYPE_CMP_SIG, 128, 12, 0);
 }
 static void *mldsa65_bp256_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 20, 0);
+                        "mldsa65_bp256", KEY_TYPE_CMP_SIG, NULL, 256, 13, 0);
 }
 
 static void *mldsa65_bp256_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_bp256", KEY_TYPE_CMP_SIG, 256, 20, 0);
+                         "mldsa65_bp256", KEY_TYPE_CMP_SIG, 256, 13, 0);
 }
 static void *mldsa65_ed25519_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_65,
-                        "mldsa65_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 21, 0);
+                        "mldsa65_ed25519", KEY_TYPE_CMP_SIG, NULL, 128, 14, 0);
 }
 
 static void *mldsa65_ed25519_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_65,
-                         "mldsa65_ed25519", KEY_TYPE_CMP_SIG, 128, 21, 0);
+                         "mldsa65_ed25519", KEY_TYPE_CMP_SIG, 128, 14, 0);
 }
 static void *mldsa87_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87", KEY_TYPE_SIG, NULL, 256, 22, 0);
+                        "mldsa87", KEY_TYPE_SIG, NULL, 256, 15, 0);
 }
 
 static void *mldsa87_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87, "mldsa87",
-                         0, 256, 22, 0);
+                         0, 256, 15, 0);
 }
 static void *p521_mldsa87_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "p521_mldsa87", KEY_TYPE_HYB_SIG, NULL, 256, 23, 0);
+                        "p521_mldsa87", KEY_TYPE_HYB_SIG, NULL, 256, 16, 0);
 }
 
 static void *p521_mldsa87_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "p521_mldsa87", KEY_TYPE_HYB_SIG, 256, 23, 0);
+                         "p521_mldsa87", KEY_TYPE_HYB_SIG, 256, 16, 0);
 }
 static void *mldsa87_p384_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_p384", KEY_TYPE_CMP_SIG, NULL, 192, 24, 0);
+                        "mldsa87_p384", KEY_TYPE_CMP_SIG, NULL, 192, 17, 0);
 }
 
 static void *mldsa87_p384_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_p384", KEY_TYPE_CMP_SIG, 192, 24, 0);
+                         "mldsa87_p384", KEY_TYPE_CMP_SIG, 192, 17, 0);
 }
 static void *mldsa87_bp384_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_bp384", KEY_TYPE_CMP_SIG, NULL, 384, 25, 0);
+                        "mldsa87_bp384", KEY_TYPE_CMP_SIG, NULL, 384, 18, 0);
 }
 
 static void *mldsa87_bp384_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_bp384", KEY_TYPE_CMP_SIG, 384, 25, 0);
+                         "mldsa87_bp384", KEY_TYPE_CMP_SIG, 384, 18, 0);
 }
 static void *mldsa87_ed448_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_ml_dsa_87,
-                        "mldsa87_ed448", KEY_TYPE_CMP_SIG, NULL, 192, 26, 0);
+                        "mldsa87_ed448", KEY_TYPE_CMP_SIG, NULL, 192, 19, 0);
 }
 
 static void *mldsa87_ed448_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_ml_dsa_87,
-                         "mldsa87_ed448", KEY_TYPE_CMP_SIG, 192, 26, 0);
+                         "mldsa87_ed448", KEY_TYPE_CMP_SIG, 192, 19, 0);
 }
 
 static void *falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "falcon512", KEY_TYPE_SIG, NULL, 128, 27, 0);
+                        "falcon512", KEY_TYPE_SIG, NULL, 128, 20, 0);
 }
 
 static void *falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "falcon512", 0, 128, 27, 0);
+                         "falcon512", 0, 128, 20, 0);
 }
 static void *p256_falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "p256_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 28, 0);
+                        "p256_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 21, 0);
 }
 
 static void *p256_falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "p256_falcon512", KEY_TYPE_HYB_SIG, 128, 28, 0);
+                         "p256_falcon512", KEY_TYPE_HYB_SIG, 128, 21, 0);
 }
 static void *rsa3072_falcon512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_512,
-                        "rsa3072_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 29,
+                        "rsa3072_falcon512", KEY_TYPE_HYB_SIG, NULL, 128, 22,
                         0);
 }
 
 static void *rsa3072_falcon512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_512,
-                         "rsa3072_falcon512", KEY_TYPE_HYB_SIG, 128, 29, 0);
+                         "rsa3072_falcon512", KEY_TYPE_HYB_SIG, 128, 22, 0);
 }
 static void *falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_512, "falconpadded512",
-                        KEY_TYPE_SIG, NULL, 128, 30, 0);
+                        KEY_TYPE_SIG, NULL, 128, 23, 0);
 }
 
 static void *falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "falconpadded512", 0, 128, 30, 0);
+                         "falconpadded512", 0, 128, 23, 0);
 }
 static void *p256_falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_512, "p256_falconpadded512",
-                        KEY_TYPE_HYB_SIG, NULL, 128, 31, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 128, 24, 0);
 }
 
 static void *p256_falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "p256_falconpadded512", KEY_TYPE_HYB_SIG, 128, 31, 0);
+                         "p256_falconpadded512", KEY_TYPE_HYB_SIG, 128, 24, 0);
 }
 static void *rsa3072_falconpadded512_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_padded_512,
-        "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, NULL, 128, 32, 0);
+        "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, NULL, 128, 25, 0);
 }
 
 static void *rsa3072_falconpadded512_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_512,
-                         "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, 128, 32,
+                         "rsa3072_falconpadded512", KEY_TYPE_HYB_SIG, 128, 25,
                          0);
 }
 static void *falcon1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_1024,
-                        "falcon1024", KEY_TYPE_SIG, NULL, 256, 33, 0);
+                        "falcon1024", KEY_TYPE_SIG, NULL, 256, 26, 0);
 }
 
 static void *falcon1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_1024,
-                         "falcon1024", 0, 256, 33, 0);
+                         "falcon1024", 0, 256, 26, 0);
 }
 static void *p521_falcon1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_falcon_1024,
-                        "p521_falcon1024", KEY_TYPE_HYB_SIG, NULL, 256, 34, 0);
+                        "p521_falcon1024", KEY_TYPE_HYB_SIG, NULL, 256, 27, 0);
 }
 
 static void *p521_falcon1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_1024,
-                         "p521_falcon1024", KEY_TYPE_HYB_SIG, 256, 34, 0);
+                         "p521_falcon1024", KEY_TYPE_HYB_SIG, 256, 27, 0);
 }
 static void *falconpadded1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_1024, "falconpadded1024",
-                        KEY_TYPE_SIG, NULL, 256, 35, 0);
+                        KEY_TYPE_SIG, NULL, 256, 28, 0);
 }
 
 static void *falconpadded1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_1024,
-                         "falconpadded1024", 0, 256, 35, 0);
+                         "falconpadded1024", 0, 256, 28, 0);
 }
 static void *p521_falconpadded1024_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_falcon_padded_1024, "p521_falconpadded1024",
-                        KEY_TYPE_HYB_SIG, NULL, 256, 36, 0);
+                        KEY_TYPE_HYB_SIG, NULL, 256, 29, 0);
 }
 
 static void *p521_falconpadded1024_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_falcon_padded_1024,
-                         "p521_falconpadded1024", KEY_TYPE_HYB_SIG, 256, 36, 0);
+                         "p521_falconpadded1024", KEY_TYPE_HYB_SIG, 256, 29, 0);
 }
 
 static void *sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "sphincssha2128fsimple", KEY_TYPE_SIG, NULL, 128, 37, 0);
+        "sphincssha2128fsimple", KEY_TYPE_SIG, NULL, 128, 30, 0);
 }
 
 static void *sphincssha2128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_128f_simple,
-                         "sphincssha2128fsimple", 0, 128, 37, 0);
+                         "sphincssha2128fsimple", 0, 128, 30, 0);
 }
 static void *p256_sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 38, 0);
+        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 31, 0);
 }
 
 static void *p256_sphincssha2128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 38, 0);
+        "p256_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 31, 0);
 }
 static void *rsa3072_sphincssha2128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 39, 0);
+        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 32, 0);
 }
 
 static void *rsa3072_sphincssha2128fsimple_gen_init(void *provctx,
                                                     int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128f_simple,
-        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 39, 0);
+        "rsa3072_sphincssha2128fsimple", KEY_TYPE_HYB_SIG, 128, 32, 0);
 }
 static void *sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "sphincssha2128ssimple", KEY_TYPE_SIG, NULL, 128, 40, 0);
+        "sphincssha2128ssimple", KEY_TYPE_SIG, NULL, 128, 33, 0);
 }
 
 static void *sphincssha2128ssimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_128s_simple,
-                         "sphincssha2128ssimple", 0, 128, 40, 0);
+                         "sphincssha2128ssimple", 0, 128, 33, 0);
 }
 static void *p256_sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 41, 0);
+        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 34, 0);
 }
 
 static void *p256_sphincssha2128ssimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 41, 0);
+        "p256_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 34, 0);
 }
 static void *rsa3072_sphincssha2128ssimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 42, 0);
+        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, NULL, 128, 35, 0);
 }
 
 static void *rsa3072_sphincssha2128ssimple_gen_init(void *provctx,
                                                     int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_128s_simple,
-        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 42, 0);
+        "rsa3072_sphincssha2128ssimple", KEY_TYPE_HYB_SIG, 128, 35, 0);
 }
 static void *sphincssha2192fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "sphincssha2192fsimple", KEY_TYPE_SIG, NULL, 192, 43, 0);
+        "sphincssha2192fsimple", KEY_TYPE_SIG, NULL, 192, 36, 0);
 }
 
 static void *sphincssha2192fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_sha2_192f_simple,
-                         "sphincssha2192fsimple", 0, 192, 43, 0);
+                         "sphincssha2192fsimple", 0, 192, 36, 0);
 }
 static void *p384_sphincssha2192fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, NULL, 192, 44, 0);
+        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, NULL, 192, 37, 0);
 }
 
 static void *p384_sphincssha2192fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_sha2_192f_simple,
-        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, 192, 44, 0);
+        "p384_sphincssha2192fsimple", KEY_TYPE_HYB_SIG, 192, 37, 0);
 }
 
 static void *sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "sphincsshake128fsimple", KEY_TYPE_SIG, NULL, 128, 45, 0);
+        "sphincsshake128fsimple", KEY_TYPE_SIG, NULL, 128, 38, 0);
 }
 
 static void *sphincsshake128fsimple_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_sphincs_shake_128f_simple,
-                         "sphincsshake128fsimple", 0, 128, 45, 0);
+                         "sphincsshake128fsimple", 0, 128, 38, 0);
 }
 static void *p256_sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 46, 0);
+        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 39, 0);
 }
 
 static void *p256_sphincsshake128fsimple_gen_init(void *provctx,
                                                   int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_shake_128f_simple,
-        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 46, 0);
+        "p256_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 39, 0);
 }
 static void *rsa3072_sphincsshake128fsimple_new_key(void *provctx) {
     return oqsx_key_new(
         PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_sphincs_shake_128f_simple,
-        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 47, 0);
+        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, NULL, 128, 40, 0);
 }
 
 static void *rsa3072_sphincsshake128fsimple_gen_init(void *provctx,
                                                      int selection) {
     return oqsx_gen_init(
         provctx, selection, OQS_SIG_alg_sphincs_shake_128f_simple,
-        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 47, 0);
+        "rsa3072_sphincsshake128fsimple", KEY_TYPE_HYB_SIG, 128, 40, 0);
 }
 
 static void *mayo1_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_1,
-                        "mayo1", KEY_TYPE_SIG, NULL, 128, 48, 0);
+                        "mayo1", KEY_TYPE_SIG, NULL, 128, 41, 0);
 }
 
 static void *mayo1_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_1, "mayo1", 0,
-                         128, 48, 0);
+                         128, 41, 0);
 }
 static void *p256_mayo1_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_1,
-                        "p256_mayo1", KEY_TYPE_HYB_SIG, NULL, 128, 49, 0);
+                        "p256_mayo1", KEY_TYPE_HYB_SIG, NULL, 128, 42, 0);
 }
 
 static void *p256_mayo1_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_1, "p256_mayo1",
-                         KEY_TYPE_HYB_SIG, 128, 49, 0);
+                         KEY_TYPE_HYB_SIG, 128, 42, 0);
 }
 static void *mayo2_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_2,
-                        "mayo2", KEY_TYPE_SIG, NULL, 128, 50, 0);
+                        "mayo2", KEY_TYPE_SIG, NULL, 128, 43, 0);
 }
 
 static void *mayo2_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_2, "mayo2", 0,
-                         128, 50, 0);
+                         128, 43, 0);
 }
 static void *p256_mayo2_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_2,
-                        "p256_mayo2", KEY_TYPE_HYB_SIG, NULL, 128, 51, 0);
+                        "p256_mayo2", KEY_TYPE_HYB_SIG, NULL, 128, 44, 0);
 }
 
 static void *p256_mayo2_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_2, "p256_mayo2",
-                         KEY_TYPE_HYB_SIG, 128, 51, 0);
+                         KEY_TYPE_HYB_SIG, 128, 44, 0);
 }
 static void *mayo3_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_3,
-                        "mayo3", KEY_TYPE_SIG, NULL, 192, 52, 0);
+                        "mayo3", KEY_TYPE_SIG, NULL, 192, 45, 0);
 }
 
 static void *mayo3_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_3, "mayo3", 0,
-                         192, 52, 0);
+                         192, 45, 0);
 }
 static void *p384_mayo3_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_3,
-                        "p384_mayo3", KEY_TYPE_HYB_SIG, NULL, 192, 53, 0);
+                        "p384_mayo3", KEY_TYPE_HYB_SIG, NULL, 192, 46, 0);
 }
 
 static void *p384_mayo3_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_3, "p384_mayo3",
-                         KEY_TYPE_HYB_SIG, 192, 53, 0);
+                         KEY_TYPE_HYB_SIG, 192, 46, 0);
 }
 static void *mayo5_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_5,
-                        "mayo5", KEY_TYPE_SIG, NULL, 256, 54, 0);
+                        "mayo5", KEY_TYPE_SIG, NULL, 256, 47, 0);
 }
 
 static void *mayo5_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_5, "mayo5", 0,
-                         256, 54, 0);
+                         256, 47, 0);
 }
 static void *p521_mayo5_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_mayo_5,
-                        "p521_mayo5", KEY_TYPE_HYB_SIG, NULL, 256, 55, 0);
+                        "p521_mayo5", KEY_TYPE_HYB_SIG, NULL, 256, 48, 0);
 }
 
 static void *p521_mayo5_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection, OQS_SIG_alg_mayo_5, "p521_mayo5",
-                         KEY_TYPE_HYB_SIG, 256, 55, 0);
+                         KEY_TYPE_HYB_SIG, 256, 48, 0);
 }
 
 static void *CROSSrsdp128balanced_new_key(void *provctx) {
     return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
                         OQS_SIG_alg_cross_rsdp_128_balanced,
-                        "CROSSrsdp128balanced", KEY_TYPE_SIG, NULL, 128, 56, 0);
+                        "CROSSrsdp128balanced", KEY_TYPE_SIG, NULL, 128, 49, 0);
 }
 
 static void *CROSSrsdp128balanced_gen_init(void *provctx, int selection) {
     return oqsx_gen_init(provctx, selection,
                          OQS_SIG_alg_cross_rsdp_128_balanced,
-                         "CROSSrsdp128balanced", 0, 128, 56, 0);
+                         "CROSSrsdp128balanced", 0, 128, 49, 0);
+}
+
+static void *OV_Is_pkc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Is_pkc,
+                        "OV_Is_pkc", KEY_TYPE_SIG, NULL, 128, 50, 0);
+}
+
+static void *OV_Is_pkc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc,
+                         "OV_Is_pkc", 0, 128, 50, 0);
+}
+static void *p256_OV_Is_pkc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Is_pkc,
+                        "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 51, 0);
+}
+
+static void *p256_OV_Is_pkc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc,
+                         "p256_OV_Is_pkc", KEY_TYPE_HYB_SIG, 128, 51, 0);
+}
+static void *OV_Ip_pkc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Ip_pkc,
+                        "OV_Ip_pkc", KEY_TYPE_SIG, NULL, 128, 52, 0);
+}
+
+static void *OV_Ip_pkc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc,
+                         "OV_Ip_pkc", 0, 128, 52, 0);
+}
+static void *p256_OV_Ip_pkc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx), OQS_SIG_alg_uov_ov_Ip_pkc,
+                        "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, NULL, 128, 53, 0);
+}
+
+static void *p256_OV_Ip_pkc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc,
+                         "p256_OV_Ip_pkc", KEY_TYPE_HYB_SIG, 128, 53, 0);
+}
+static void *OV_Is_pkc_skc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_uov_ov_Is_pkc_skc, "OV_Is_pkc_skc",
+                        KEY_TYPE_SIG, NULL, 128, 54, 0);
+}
+
+static void *OV_Is_pkc_skc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc_skc,
+                         "OV_Is_pkc_skc", 0, 128, 54, 0);
+}
+static void *p256_OV_Is_pkc_skc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_uov_ov_Is_pkc_skc, "p256_OV_Is_pkc_skc",
+                        KEY_TYPE_HYB_SIG, NULL, 128, 55, 0);
+}
+
+static void *p256_OV_Is_pkc_skc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Is_pkc_skc,
+                         "p256_OV_Is_pkc_skc", KEY_TYPE_HYB_SIG, 128, 55, 0);
+}
+static void *OV_Ip_pkc_skc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_uov_ov_Ip_pkc_skc, "OV_Ip_pkc_skc",
+                        KEY_TYPE_SIG, NULL, 128, 56, 0);
+}
+
+static void *OV_Ip_pkc_skc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc_skc,
+                         "OV_Ip_pkc_skc", 0, 128, 56, 0);
+}
+static void *p256_OV_Ip_pkc_skc_new_key(void *provctx) {
+    return oqsx_key_new(PROV_OQS_LIBCTX_OF(provctx),
+                        OQS_SIG_alg_uov_ov_Ip_pkc_skc, "p256_OV_Ip_pkc_skc",
+                        KEY_TYPE_HYB_SIG, NULL, 128, 57, 0);
+}
+
+static void *p256_OV_Ip_pkc_skc_gen_init(void *provctx, int selection) {
+    return oqsx_gen_init(provctx, selection, OQS_SIG_alg_uov_ov_Ip_pkc_skc,
+                         "p256_OV_Ip_pkc_skc", KEY_TYPE_HYB_SIG, 128, 57, 0);
 }
 
 ///// OQS_TEMPLATE_FRAGMENT_KEYMGMT_CONSTRUCTORS_END
@@ -1395,13 +1408,6 @@ static void *CROSSrsdp128balanced_gen_init(void *provctx, int selection) {
         {0, NULL}};
 
 ///// OQS_TEMPLATE_FRAGMENT_KEYMGMT_FUNCTIONS_START
-MAKE_SIG_KEYMGMT_FUNCTIONS(dilithium2)
-MAKE_SIG_KEYMGMT_FUNCTIONS(p256_dilithium2)
-MAKE_SIG_KEYMGMT_FUNCTIONS(rsa3072_dilithium2)
-MAKE_SIG_KEYMGMT_FUNCTIONS(dilithium3)
-MAKE_SIG_KEYMGMT_FUNCTIONS(p384_dilithium3)
-MAKE_SIG_KEYMGMT_FUNCTIONS(dilithium5)
-MAKE_SIG_KEYMGMT_FUNCTIONS(p521_dilithium5)
 MAKE_SIG_KEYMGMT_FUNCTIONS(mldsa44)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p256_mldsa44)
 MAKE_SIG_KEYMGMT_FUNCTIONS(rsa3072_mldsa44)
@@ -1452,6 +1458,14 @@ MAKE_SIG_KEYMGMT_FUNCTIONS(p384_mayo3)
 MAKE_SIG_KEYMGMT_FUNCTIONS(mayo5)
 MAKE_SIG_KEYMGMT_FUNCTIONS(p521_mayo5)
 MAKE_SIG_KEYMGMT_FUNCTIONS(CROSSrsdp128balanced)
+MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Is_pkc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Is_pkc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Ip_pkc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Ip_pkc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Is_pkc_skc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Is_pkc_skc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(OV_Ip_pkc_skc)
+MAKE_SIG_KEYMGMT_FUNCTIONS(p256_OV_Ip_pkc_skc)
 
 MAKE_KEM_KEYMGMT_FUNCTIONS(frodo640aes, OQS_KEM_alg_frodokem_640_aes, 128)
 
@@ -1489,22 +1503,6 @@ MAKE_KEM_KEYMGMT_FUNCTIONS(frodo1344shake, OQS_KEM_alg_frodokem_1344_shake, 256)
 
 MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p521_frodo1344shake,
                                OQS_KEM_alg_frodokem_1344_shake, 256)
-MAKE_KEM_KEYMGMT_FUNCTIONS(kyber512, OQS_KEM_alg_kyber_512, 128)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p256_kyber512, OQS_KEM_alg_kyber_512, 128)
-
-MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x25519_kyber512, OQS_KEM_alg_kyber_512, 128, 0)
-MAKE_KEM_KEYMGMT_FUNCTIONS(kyber768, OQS_KEM_alg_kyber_768, 192)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p384_kyber768, OQS_KEM_alg_kyber_768, 192)
-
-MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x448_kyber768, OQS_KEM_alg_kyber_768, 192, 0)
-
-MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x25519_kyber768, OQS_KEM_alg_kyber_768, 128, 0)
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p256_kyber768, OQS_KEM_alg_kyber_768, 128)
-MAKE_KEM_KEYMGMT_FUNCTIONS(kyber1024, OQS_KEM_alg_kyber_1024, 256)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p521_kyber1024, OQS_KEM_alg_kyber_1024, 256)
 MAKE_KEM_KEYMGMT_FUNCTIONS(mlkem512, OQS_KEM_alg_ml_kem_512, 128)
 
 MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p256_mlkem512, OQS_KEM_alg_ml_kem_512, 128)
@@ -1521,7 +1519,7 @@ MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(SecP256r1MLKEM768, OQS_KEM_alg_ml_kem_768, 128)
 MAKE_KEM_KEYMGMT_FUNCTIONS(mlkem1024, OQS_KEM_alg_ml_kem_1024, 256)
 
 MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p521_mlkem1024, OQS_KEM_alg_ml_kem_1024, 256)
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p384_mlkem1024, OQS_KEM_alg_ml_kem_1024, 192)
+MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(SecP384r1MLKEM1024, OQS_KEM_alg_ml_kem_1024, 192)
 MAKE_KEM_KEYMGMT_FUNCTIONS(bikel1, OQS_KEM_alg_bike_l1, 128)
 
 MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p256_bikel1, OQS_KEM_alg_bike_l1, 128)
@@ -1535,17 +1533,4 @@ MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x448_bikel3, OQS_KEM_alg_bike_l3, 192, 0)
 MAKE_KEM_KEYMGMT_FUNCTIONS(bikel5, OQS_KEM_alg_bike_l5, 256)
 
 MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p521_bikel5, OQS_KEM_alg_bike_l5, 256)
-MAKE_KEM_KEYMGMT_FUNCTIONS(hqc128, OQS_KEM_alg_hqc_128, 128)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p256_hqc128, OQS_KEM_alg_hqc_128, 128)
-
-MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x25519_hqc128, OQS_KEM_alg_hqc_128, 128, 0)
-MAKE_KEM_KEYMGMT_FUNCTIONS(hqc192, OQS_KEM_alg_hqc_192, 192)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p384_hqc192, OQS_KEM_alg_hqc_192, 192)
-
-MAKE_KEM_ECX_KEYMGMT_FUNCTIONS(x448_hqc192, OQS_KEM_alg_hqc_192, 192, 0)
-MAKE_KEM_KEYMGMT_FUNCTIONS(hqc256, OQS_KEM_alg_hqc_256, 256)
-
-MAKE_KEM_ECP_KEYMGMT_FUNCTIONS(p521_hqc256, OQS_KEM_alg_hqc_256, 256)
 ///// OQS_TEMPLATE_FRAGMENT_KEYMGMT_FUNCTIONS_END
